/////////////////////////////////////////////////////////////
// Schmoo2Spreadsheet - Generate a text schmoo file
//
// Authors         : Ken Stevens <kstevens@ece.utah.edu>
// Mod Date        : 5 April 2008
// Revision        : 0.1
// Status          : 
// Bug Reports     : Ken Stevens <kstevens@ece.utah.edu>
//
// This class will parse an LVS500 Schmoo binary data file
// and turn it into a text file suitable for a document or
// a spreadsheet for formatting.
//
// The format was reverse engineered without documentation
// from sample schmoo files, so there still may be some bugs.
// 
// Bugs:
//   Jun Bok You extended the parsing to include more binary
//   characters that are possible between descriptors.
//
// Improvements:
//
// Comments:
//
// Commands:
//
///////////////////////////////////////////////////////////////



#include <vector>


enum SCHMOOTYPE
  { BOGUS  = 1,
    PASSED = 2,
    FAILED = 3 };

#define BOGUSC	'0'
#define PASSEDC 'X'
#define FAILEDC '-'


class SchmooData
{

  // functions:

 public:

  SchmooData() { title_ = NULL; }
  virtual ~SchmooData();

  void setTitle(const char *txt) {
    title_ = (char *) malloc(1+ strlen(txt));
    strcpy(title_, txt);
  }
  void addValue(const char *txt) {
    char *cp = (char *) malloc(1+ strlen(txt));
    strcpy(cp, txt);
    values_.push_back(cp);
  }
  const char *title() { return title_; }
  const char *value(int i) { return values_[i]; }
  unsigned int size() { return values_.size(); }

  // Data

 private:

  char *title_;
  std::vector<char *> values_;

};




class Schmoo
{

  // Functions:

 public:
  Schmoo();
  virtual ~Schmoo();

  void setDate(const char *month, int day, int year);
  void setTime(const char *time);

  void print(int tabp);

  const char *month() { return (const char *)month_; }
  int day() {return day_; }
  int year() { return year_; }
  const char *time() { return (const char *)time_; }

  // This must be called after initializing x and y, and before setting data
  void initData();
  // initData must be called before setting data.
  void setData(unsigned int xi, unsigned int yi, SCHMOOTYPE v) {
    if (data_ && xi < x->size() && yi < y->size()) data_[yi][xi] = v; }
  SCHMOOTYPE getData(unsigned int xi, unsigned int yi) {
    if (data_ && xi < x->size() && yi < y->size()) return data_[yi][xi];
    else return BOGUS; }

  // Data members:

 public:

  SchmooData *x, *y;

 private:

  char *month_, *time_;
  int day_, year_;
  SCHMOOTYPE **data_;	// stored as [y][x] array

};



